@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2015 The Music Player Daemon Project
+   (c) 2003-2017 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -40,6 +40,7 @@
 enum {
 	INTLEN = (sizeof(int) * CHAR_BIT + 1) / 3 + 1,
 	LONGLONGLEN = (sizeof(long long) * CHAR_BIT + 1) / 3 + 1,
+	FLOATLEN = LONGLONGLEN + 8,
 };
 
 static void
@@ -167,12 +168,46 @@ bool
 mpd_send_float_command(struct mpd_connection *connection, const char *command,
 		       float arg)
 {
-	char arg_string[INTLEN];
+	char arg_string[FLOATLEN];
 
 	snprintf(arg_string, sizeof(arg_string), "%f", arg);
 	return mpd_send_command(connection, command, arg_string, NULL);
 }
 
+bool
+mpd_send_u_f_command(struct mpd_connection *connection, const char *command,
+		     unsigned arg1, float arg2)
+{
+	char arg1_string[INTLEN], arg2_string[FLOATLEN];
+
+	snprintf(arg1_string, sizeof(arg1_string), "%u", arg1);
+	snprintf(arg2_string, sizeof(arg2_string), "%.3f", arg2);
+	return mpd_send_command(connection, command,
+				arg1_string, arg2_string, NULL);
+}
+
+bool
+mpd_send_u_s_command(struct mpd_connection *connection, const char *command,
+		     unsigned arg1, const char *arg2)
+{
+	char arg1_string[INTLEN];
+
+	snprintf(arg1_string, sizeof(arg1_string), "%i", arg1);
+	return mpd_send_command(connection, command,
+				arg1_string, arg2, NULL);
+}
+
+bool
+mpd_send_u_s_s_command(struct mpd_connection *connection, const char *command,
+		       unsigned arg1, const char *arg2, const char *arg3)
+{
+	char arg1_string[INTLEN];
+
+	snprintf(arg1_string, sizeof(arg1_string), "%i", arg1);
+	return mpd_send_command(connection, command,
+				arg1_string, arg2, arg3, NULL);
+}
+
 bool
 mpd_send_s_u_command(struct mpd_connection *connection, const char *command,
 		     const char *arg1, unsigned arg2)
@@ -207,6 +242,19 @@ mpd_send_i_range_command(struct mpd_connection *connection,
 				arg1_string, arg2_string, NULL);
 }
 
+bool
+mpd_send_u_range_command(struct mpd_connection *connection,
+			 const char *command, unsigned arg1,
+			 unsigned start, unsigned end)
+{
+	char arg1_string[INTLEN + 1], arg2_string[INTLEN * 2 + 1];
+
+	snprintf(arg1_string, sizeof(arg1_string), "%u", arg1);
+	format_range(arg2_string, sizeof(arg2_string), start, end);
+	return mpd_send_command(connection, command,
+				arg1_string, arg2_string, NULL);
+}
+
 bool
 mpd_send_range_u_command(struct mpd_connection *connection,
 			 const char *command,
@@ -226,7 +274,7 @@ mpd_send_ll_command(struct mpd_connection *connection, const char *command,
 {
 	char arg_string[LONGLONGLEN];
 
-#ifdef WIN32
+#ifdef _WIN32
 	snprintf(arg_string, sizeof(arg_string), "%ld", (long)arg);
 #else
 	snprintf(arg_string, sizeof(arg_string), "%lld", arg);
