@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2015 The Music Player Daemon Project
+   (c) 2003-2017 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -33,6 +33,7 @@
 #include <mpd/status.h>
 #include <mpd/pair.h>
 #include <mpd/audio_format.h>
+#include "iaf.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -192,36 +193,6 @@ parse_mpd_state(const char *p)
 		return MPD_STATE_UNKNOWN;
 }
 
-static void
-parse_audio_format(struct mpd_audio_format *audio_format, const char *p)
-{
-	char *endptr;
-
-	audio_format->sample_rate = strtoul(p, &endptr, 10);
-	if (*endptr == ':') {
-		p = endptr + 1;
-
-		if (p[0] == 'f' && p[1] == ':') {
-			audio_format->bits = MPD_SAMPLE_FORMAT_FLOAT;
-			p += 2;
-		} else if (p[0] == 'd' && p[1] == 's' &&
-			   p[2] == 'd' && p[3] == ':') {
-			audio_format->bits = MPD_SAMPLE_FORMAT_DSD;
-			p += 4;
-		} else {
-			audio_format->bits = strtoul(p, &endptr, 10);
-			p = *endptr == ':' ? endptr + 1 : NULL;
-		}
-
-		audio_format->channels = p != NULL
-			? strtoul(p, NULL, 10)
-			: 0;
-	} else {
-		audio_format->bits = 0;
-		audio_format->channels = 0;
-	}
-}
-
 void
 mpd_status_feed(struct mpd_status *status, const struct mpd_pair *pair)
 {
@@ -270,9 +241,7 @@ mpd_status_feed(struct mpd_status *status, const struct mpd_pair *pair)
 		if (status->elapsed_time == 0)
 			status->elapsed_time = status->elapsed_ms / 1000;
 	} else if (strcmp(pair->name, "error") == 0) {
-		if (status->error != NULL)
-			free(status->error);
-
+		free(status->error);
 		status->error = strdup(pair->value);
 	} else if (strcmp(pair->name, "xfade") == 0)
 		status->crossfade = atoi(pair->value);
@@ -283,11 +252,11 @@ mpd_status_feed(struct mpd_status *status, const struct mpd_pair *pair)
 	else if (strcmp(pair->name, "updating_db") == 0)
 		status->update_id = atoi(pair->value);
 	else if (strcmp(pair->name, "audio") == 0)
-		parse_audio_format(&status->audio_format, pair->value);
+		mpd_parse_audio_format(&status->audio_format, pair->value);
 }
 
 void mpd_status_free(struct mpd_status * status) {
-	if (status->error) free(status->error);
+	free(status->error);
 	free(status);
 }
 
@@ -407,9 +376,7 @@ mpd_status_get_kbit_rate(const struct mpd_status *status)
 const struct mpd_audio_format *
 mpd_status_get_audio_format(const struct mpd_status *status)
 {
-	return status->audio_format.sample_rate > 0 ||
-		status->audio_format.bits > 0 ||
-		status->audio_format.channels > 0
+	return !mpd_audio_format_is_empty(&status->audio_format)
 		? &status->audio_format
 		: NULL;
 }
